﻿using System.Drawing;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Grid;

namespace PdfSample
{
    class Program
    {
        private static int GRID_LEFT = 100;
        private static int GRID_TOP = 100;
        private static int GRID_WIDTH = 400;
        private static int GRID_HEIGHT = 400;

        static void Main(string[] args)
        {
            //Creates a new PDF document.
            PdfDocument pdfDocument = new PdfDocument();
            var marginSize = 15;
            pdfDocument.PageSettings.Margins.All = marginSize;
            PdfPage pdfPage = pdfDocument.Pages.Add();

            //Creates a new PdfGrid.
            PdfGrid pdfGrid = new PdfGrid();
            pdfGrid.Style.BackgroundBrush = new PdfSolidBrush(Color.WhiteSmoke);
            pdfGrid.Style.CellPadding = new PdfPaddings(3, 3, 3, 3);
            pdfGrid.RepeatHeader = true;
            //Adds three columns.
            pdfGrid.Columns.Add(3);
            pdfGrid.Columns[2].Format = new PdfStringFormat()
            {
                Alignment = PdfTextAlignment.Right,
                CharacterSpacing = 0.5f
            };
            pdfGrid.Columns[2].Width = 50;
            //Adds header.
            pdfGrid.Headers.Add(1);
            PdfGridRow pdfGridHeader = pdfGrid.Headers[0];
            pdfGridHeader.Cells[0].Value = "Employee ID";
            pdfGridHeader.Cells[1].Value = "Employee Name";
            pdfGridHeader.Cells[2].Value = "Salary";
            pdfGridHeader.Style = new PdfGridRowStyle()
            {
                Font = new PdfStandardFont(PdfFontFamily.Helvetica, 8f, PdfFontStyle.Bold),
                BackgroundBrush = new PdfSolidBrush(Color.AntiqueWhite)
            };
            //Adds rows.
            for (var i = 0; i < 400; ++i)
            {
                PdfGridRow pdfGridRow = pdfGrid.Rows.Add();
                pdfGridRow.Cells[0].Value = "E01";
                pdfGridRow.Cells[1].Value = "Clay";
                pdfGridRow.Cells[2].Value = "$10,000";
            }
            //Draws the PdfGrid.
            PdfGridLayoutResult gridResult = pdfGrid.Draw(pdfPage,
                new RectangleF(GRID_LEFT, GRID_TOP, GRID_WIDTH, GRID_HEIGHT),
                new PdfGridLayoutFormat()
                {
                    Break = PdfLayoutBreakType.FitElement,
                    Layout = PdfLayoutType.Paginate,
                    PaginateBounds = new RectangleF(GRID_LEFT, GRID_TOP, GRID_WIDTH, GRID_HEIGHT)
                });


            // Footer.
            var font = new PdfStandardFont(PdfFontFamily.Helvetica, 10f, PdfFontStyle.Bold);
            PdfPageTemplateElement footer = new PdfPageTemplateElement(new RectangleF(0, 0, pdfDocument.Pages[0].GetClientSize().Width, 50));
            PdfPageNumberField pageNumber = new PdfPageNumberField(font);
            PdfPageCountField count = new PdfPageCountField(font);
            PdfCompositeField compositeField = new PdfCompositeField(font, "Page {0} of {1}", pageNumber, count);
            compositeField.Bounds = footer.Bounds;
            compositeField.Draw(footer.Graphics, new PointF(390, 0));
            pdfDocument.Template.Bottom = footer;

            //Saves the document.
            pdfDocument.Save(@"c:\temp\Output.pdf");
            pdfDocument.Close(true);
        }
    }
}
